### Hello World
[![PyPi Pubish](https://github.com/rajendrakumaryadav/greetworld/actions/workflows/publish_pypi.yml/badge.svg)](https://github.com/rajendrakumaryadav/greetworld/actions/workflows/publish_pypi.yml)

It is based on Python and return

```bash
$python
> from greetworld import greet
> hello = greet.greet()
> print(hello.say_hello())
Hello, World!
> hello = greet.greet("Rajendra")
> print(hello.say_hello())
Hello, Rajendra!
```
